YARP 2.1.0 (2006-10-28)                                                {#v2_1_0}
=======================

Contributors
------------

This is a list of people that contributed to this release (generated from the
git history using `git shortlog -ens --no-merges v2.0.4...v2.1.0`):

```
   270	Paul Fitzpatrick <paulfitz@alum.mit.edu>
    52	YARP Developers <yarp0-devel@lists.sourceforge.net>
    34	Lorenzo Natale <lorenzo.natale@iit.it>
    17	Giorgio Metta <giorgio.metta@iit.it>
     6	Alexandre Bernardino <alex@isr.ist.utl.pt>
     3	Michael Bucko <m.c.bucko@gmail.com>
     2	Francesco Orabona <francesco@orabona.com>
     1	Arjan Gijsberts <arjan.gijsberts@idiap.ch>
     1	Matteo Brunettini <matteo.brunettini@iit.it>
```
